@@ -1,6 +1,10 @@
 
+API_BASE_URL = "https://api.publibike.ch/v1/public/stations/"
+
 class Constants():
     ID = "id"
+    STATE = "state"
+    ACTIVE = "Active"
     NAME = "name"
     LATITUDE = "latitude"
     LONGITUDE = "longitude"
