@@ -7,11 +7,11 @@ from pypublibike.location import Location
 
 class TestStation(unittest.TestCase):
 
-    def getSampleJson(self, _id):
+    @staticmethod
+    def getSampleJson(_unused):
         with open(os.path.join("test", "test_data", "station_happyday.json")) as f:
             sampleJson = f.read()
-        sampleJson = json.loads(sampleJson)
-        return sampleJson
+            return json.loads(sampleJson)
 
     def test_happyday(self):
         stationId = 123
@@ -20,6 +20,7 @@ class TestStation(unittest.TestCase):
 
         station.refresh()
         self.assertEqual(station.name, "Köniz Zentrum")
+        self.assertTrue(station.active)
         self.assertEqual(station.address, "Bläuacker 10")
         self.assertEqual(station.zip, 3098)
         self.assertEqual(station.city, "Köniz")
@@ -29,7 +30,8 @@ class TestStation(unittest.TestCase):
         self.assertEqual(station.location, Location(46.9229774, 7.4141121))
         self.assertEqual(station.stationId, stationId)
 
-    def test_live(self):
+    @staticmethod
+    def test_live():
         station = Station(421)
         station.refresh()
 
